diff --git a/src/assets/images/arrow.png b/src/assets/images/arrow.png
new file mode 100644
index 0000000..adb86a6
Binary files /dev/null and b/src/assets/images/arrow.png differ
diff --git a/src/assets/images/getStarted.png b/src/assets/images/getStarted.png
new file mode 100644
index 0000000..ea34938
Binary files /dev/null and b/src/assets/images/getStarted.png differ
diff --git a/src/assets/images/stack.png b/src/assets/images/stack.png
new file mode 100644
index 0000000..83bd64a
Binary files /dev/null and b/src/assets/images/stack.png differ
diff --git a/src/components/Card/HomeCard.jsx b/src/components/Card/HomeCard.jsx
index 9b80e7a..1087779 100644
--- a/src/components/Card/HomeCard.jsx
+++ b/src/components/Card/HomeCard.jsx
@@ -28,12 +28,7 @@ const HomeCard = () => {
Published: March 13, 2020
-
+
Multichain over Blockchain — A reality check on security threat
{
{
-
+ {
>
-
+
Stay up to date with Rubix
diff --git a/src/components/HomePage/Client.jsx b/src/components/HomePage/Client.jsx
index 0b5fe58..d700339 100644
--- a/src/components/HomePage/Client.jsx
+++ b/src/components/HomePage/Client.jsx
@@ -28,7 +28,7 @@ const Client = () => {
};
return (
{
backgroundSize={"cover"}
display={"grid"}
placeContent={"center"}
+ position="relative"
+ zIndex={"2"}
sx={{
+ "&::after": {
+ content: '""',
+ position: "absolute",
+ top: 0,
+ left: 0,
+ width: "100%",
+ height: "100%",
+ backgroundColor: "rgba(0, 0, 0, 0.5)",
+ zIndex: "-1",
+ },
+
"@media (max-width: 1024px)": {
height: "70vh",
},
diff --git a/src/components/LearnPage/GetStarted.jsx b/src/components/LearnPage/GetStarted.jsx
new file mode 100644
index 0000000..5539310
--- /dev/null
+++ b/src/components/LearnPage/GetStarted.jsx
@@ -0,0 +1,94 @@
+import { Box, Container, Image, Text } from "@chakra-ui/react";
+import { Tabs, TabList, TabPanels, Tab, TabPanel } from "@chakra-ui/react";
+import getStarted from "../../assets/images/getStarted.png";
+import getStarted1 from "../../assets/images/getStarted.png";
+import getStarted2 from "../../assets/images/getStarted.png";
+import getStarted3 from "../../assets/images/getStarted.png";
+
+const GetStarted = () => {
+ return (
+
+
+
+ Get Started With Rubix
+
+
+ Rubix allows developers to build on a fast, secure, and scalable chain
+ that has a unique approach to data sharing, objects.
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ - Start by reading our whitepaper
+
+
+ - Start by reading our whitepaper
+
+
+ - Start by reading our whitepaper
+
+
+ - Start by reading our whitepaper
+
+
+
+
+
+
+ );
+};
+
+export default GetStarted;
diff --git a/src/components/LearnPage/LearnDev.jsx b/src/components/LearnPage/LearnDev.jsx
index a4ae335..0ac223f 100644
--- a/src/components/LearnPage/LearnDev.jsx
+++ b/src/components/LearnPage/LearnDev.jsx
@@ -1,3 +1,4 @@
+/* eslint-disable no-unused-vars */
import { Box, Container, Text, Image, Button } from "@chakra-ui/react";
import LearnCard from "../Card/LearnCard";
import chainx from "../../assets/images/LearnCard2.png";
diff --git a/src/components/LearnPage/WhyRubix.jsx b/src/components/LearnPage/WhyRubix.jsx
index 5499bef..3f8b74c 100644
--- a/src/components/LearnPage/WhyRubix.jsx
+++ b/src/components/LearnPage/WhyRubix.jsx
@@ -1,4 +1,4 @@
-import { Box, Container, Text } from "@chakra-ui/react";
+import { Box, Container, Image, Text } from "@chakra-ui/react";
import {
Accordion,
AccordionItem,
@@ -7,6 +7,38 @@ import {
AccordionIcon,
} from "@chakra-ui/react";
import bg from "../../assets/images/whyRubix.png";
+import cube from "../../assets/images/cube.png";
+
+const accordion = [
+ {
+ id: 1,
+ title: `Unlimited concurrent transactions`,
+ content: `The Rubix network supports millions of concurrent transactions
+ by eliminating the need to queue transactions for the
+ blockchain.`,
+ },
+ {
+ id: 2,
+ title: `Scalability`,
+ content: `The Rubix network supports millions of concurrent transactions
+ by eliminating the need to queue transactions for the
+ blockchain.`,
+ },
+ {
+ id: 3,
+ title: `Truly decentralised, secure and private`,
+ content: `The Rubix network supports millions of concurrent transactions
+ by eliminating the need to queue transactions for the
+ blockchain.`,
+ },
+ {
+ id: 4,
+ title: `ROI friendly`,
+ content: `The Rubix network supports millions of concurrent transactions
+ by eliminating the need to queue transactions for the
+ blockchain.`,
+ },
+];
const WhyRubix = () => {
return (
@@ -18,9 +50,8 @@ const WhyRubix = () => {
{
>
Why developers choose Rubix
-
-
-
-
-
-
- Section 1 title
-
-
-
-
-
- Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do
- eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut
- enim ad minim veniam, quis nostrud exercitation ullamco laboris
- nisi ut aliquip ex ea commodo consequat.
-
-
-
-
-
-
-
- Section 2 title
-
-
-
-
-
- Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do
- eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut
- enim ad minim veniam, quis nostrud exercitation ullamco laboris
- nisi ut aliquip ex ea commodo consequat.
-
-
-
+
+
+
+ {accordion.map((accord) => (
+ <>
+
+
diff --git a/src/components/HomePage/Subnets.jsx b/src/components/HomePage/Subnets.jsx
index c64b85d..84a4c6b 100644
--- a/src/components/HomePage/Subnets.jsx
+++ b/src/components/HomePage/Subnets.jsx
@@ -14,28 +14,53 @@ import cube from "../../assets/images/cube.png";
import Component3 from "../SubnetsComponent/Component3";
import Component4 from "../SubnetsComponent/Component4";
import SubnetPage2 from "../SubnetsComponent/SubnetPage2";
-import { useState } from "react";
+import { useEffect, useState } from "react";
const SubnetContent = {
heading: `decentralised Auto Syncing subnets`,
};
const Subnets = () => {
- const [showSubnetPage, setShowSubnetPage] = useState(true);
+ const [showSubnet2, setShowSubnet2] = useState(false);
+ const [showStickyPosition, setShowStickyPosition] = useState(false);
- const handleImageClick = () => {
- setShowSubnetPage(false);
- };
+ useEffect(() => {
+ const handleScroll = () => {
+ const threshold = 800; // Adjust this threshold according to your design
+ if (window.scrollY > threshold) {
+ setShowStickyPosition(true);
+ }
+ };
- const handleSubnetPage2Click = () => {
- setShowSubnetPage(true); // Show Subnets component when SubnetPage2 is clicked
- };
+ window.addEventListener("scroll", handleScroll);
+
+ return () => {
+ window.removeEventListener("scroll", handleScroll);
+ };
+ }, []);
+
+ useEffect(() => {
+ if (showStickyPosition) {
+ setShowSubnet2(true);
+ }
+ }, [showStickyPosition]);
+ // const [showSubnetPage, setShowSubnetPage] = useState(true);
+
+ // const handleImageClick = () => {
+ // setShowSubnetPage(false);
+ // };
+
+ // const handleSubnetPage2Click = () => {
+ // setShowSubnetPage(true); // Show Subnets component when SubnetPage2 is clicked
+ // };
return (
<>
- {showSubnetPage ? (
+ {!showSubnet2 ? (
{
cursor={"pointer"}
transform="translateY(-10%)"
animation="floatAnimation 2s infinite alternate"
- onClick={handleImageClick}
+ // onClick={handleImageClick}
sx={{
"@keyframes floatAnimation": {
"0%": {
@@ -134,7 +159,7 @@ const Subnets = () => {
) : (
-
+
)}
>
);